@@ -22,11 +22,7 @@
 #include <QShortcut>
 #include <QKeySequence>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QtWidgets>
-#else
-#include <QtGui>
-#endif
 
 #include <QMessageBox>
 
